@@ -2,6 +2,14 @@
 decoupage: a view with webob to index and serve static content
 """
 
+# TODO:
+# files like `index.ini`
+# -> http://k0s.org/portfolio/ideas/#index.ini#
+#
+# oops. Handle it better
+# - either # is a magic hide character
+# - or you urlescape that guy
+
 import os
 import sys
 
@@ -44,7 +52,7 @@ class Decoupage(object):
         self.auto_reload = self.auto_reload.lower() == 'true'
         self.cascade = self.cascade.lower() == 'true'
         self.directory = self.directory.rstrip(os.path.sep)
-        assert os.path.isdir(self.directory)
+        assert os.path.isdir(self.directory), "'%s' is not a directory" % self.directory
         self.template_directories = self.template_directories.split() # no spaces in directory names, for now
 
         for directory in self.template_directories:
@@ -243,7 +251,21 @@ class Decoupage(object):
             filetype = 'file'
             if os.path.isdir(filepath):
                 filetype = 'directory'
-            modified = os.path.getmtime(filepath)
+            try:
+                modified = os.path.getmtime(filepath)
+            except OSError:
+                # the file (mysteriously) may not exist by this time(!)
+                #  File "/home/jhammel/web/src/decoupage/decoupage/web.py", line 114, in __call__
+                #    res = self.get(request)
+                #  File "/home/jhammel/web/src/decoupage/decoupage/web.py", line 162, in get
+                #    files = self.filedata(path, directory, conf)
+                #  File "/home/jhammel/web/src/decoupage/decoupage/web.py", line 246, in filedata
+                #    modified = os.path.getmtime(filepath)
+                #  File "/home/jhammel/web/lib/python2.6/genericpath.py", line 54, in getmtime
+                #    return os.stat(filename).st_mtime
+                # OSError: [Errno 2] No such file or directory: '/home/jhammel/web/site/portfolio/ideas/.#index.ini'
+                continue # wt{h,f}???
+
             modified = datetime.fromtimestamp(modified)
             data = {'path' : '%s/%s' % (path.rstrip('/'), i),
                     'name': i,
